@@ -1,4 +1,4 @@
-from sqlalchemy import Table, Column, func
+from sqlalchemy import Table, Column
 from sqlalchemy import String
 from fsu.model import common_columns
 
