@@ -5,26 +5,15 @@ from os import urandom
 
 RedisLock = namedtuple("RedisLock", ["lock"])
 
-def make_redis_lock(get_redis):
-    redis = None
-
-    async def get_redis_():
-        nonlocal redis
-
-        if redis is None:
-            redis = await get_redis()
-
-        return redis
-
+def make_redis_lock(redis):
     @asynccontextmanager
     async def lock(key, timeout = 60):
-        r = await get_redis_()
         v = urandom(20)
 
         accuired = False
 
         while not accuired:
-            accuired = await r.set(key, v, expire=timeout, exist="SET_IF_NOT_EXIST")
+            accuired = await redis.set(key, v, expire=timeout, exist="SET_IF_NOT_EXIST")
 
             if not accuired:
                 await sleep(1)
@@ -32,7 +21,7 @@ def make_redis_lock(get_redis):
         try:
             yield
         finally:
-            await r.eval("""
+            await redis.eval("""
                 if redis.call("get", KEYS[1]) == ARGV[1]
                 then
                     return redis.call("del", KEYS[1])
