@@ -48,7 +48,7 @@ class GenericMeta(type):
             "__generic_model__": create_model("V", v=(t, ...))
         })
 
-class CommaSeperated(Generic[T], metaclass=GenericMeta):
+class CommaSeparated(Generic[T], metaclass=GenericMeta):
     @classmethod
     def __get_validators__(cls):
         yield cls.validate
